import * as React from 'react';
import * as ReactDom from 'react-dom';
import { Version } from '@microsoft/sp-core-library';
import {
  IPropertyPaneConfiguration,
  PropertyPaneTextField
} from '@microsoft/sp-property-pane';
import { BaseClientSideWebPart } from '@microsoft/sp-webpart-base';
import { WebPartContext } from "@microsoft/sp-webpart-base";

import * as strings from 'ReportMaintenanceWebPartStrings';
import ReportMaintenance from './components/ReportMaintenance';
import { IReportMaintenanceProps } from './components/IReportMaintenanceProps';

export interface IReportMaintenanceWebPartProps {
  description: string;
  description2: string;
  spcontext:WebPartContext;
}
export interface IReportMaintenanceState {
  description: string;
}
export default class ReportMaintenanceWebPart extends BaseClientSideWebPart<IReportMaintenanceProps> {

  public render(): void {
    const element: React.ReactElement<IReportMaintenanceProps> = React.createElement(
      ReportMaintenance,
      {
        description: this.properties.description,
        description2: this.properties.description2,
        webURL:this.context.pageContext.web.absoluteUrl,
        context:this.context,
        listName: this.properties.listName
      }
    );

    ReactDom.render(element, this.domElement);
  }

  protected onDispose(): void {
    ReactDom.unmountComponentAtNode(this.domElement);
  }

  protected get dataVersion(): Version {
    return Version.parse('1.0');
  }

  protected getPropertyPaneConfiguration(): IPropertyPaneConfiguration {
    return {
      pages: [
        {
          header: {
            description: strings.PropertyPaneDescription
          },
          groups: [
            {
              groupName: strings.BasicGroupName,
              groupFields: [
                PropertyPaneTextField('description', {
                  label: strings.DescriptionFieldLabel
                })
              ]
            }
          ]
        }
      ]
    };
  }
}
